summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneyreport.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit902ba103f2215bcefa22d62b1c9138aa4b88891c (patch)
tree63ef88424b9be33a31e5a8de61343fb8d7633937 /kmymoney2/mymoney/mymoneyreport.h
parent7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2 (diff)
downloadkmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.tar.gz
kmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/mymoney/mymoneyreport.h')
-rw-r--r--kmymoney2/mymoney/mymoneyreport.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/mymoney/mymoneyreport.h b/kmymoney2/mymoney/mymoneyreport.h
index f7e38ea..a04573f 100644
--- a/kmymoney2/mymoney/mymoneyreport.h
+++ b/kmymoney2/mymoney/mymoneyreport.h
@@ -64,7 +64,7 @@ public:
enum EReportType { eNoReport = 0, ePivotTable, eQueryTable, eInfoTable };
enum EColumnType { eNoColumns = 0, eDays = 1, eMonths = 1, eBiMonths = 2, eQuarters = 3, eWeeks = 7, eYears = 12 };
- // if you add bits to this bittqmask, start with the value currently assigned to eTQCend and update its value afterwards
+ // if you add bits to this bitmask, start with the value currently assigned to eTQCend and update its value afterwards
// also don't forget to add column names to kQueryColumnsText in mymoneyreport.cpp
enum EQueryColumns { eTQCnone = 0x0, eTQCbegin = 0x1, eTQCnumber = 0x1, eTQCpayee = 0x2, eTQCcategory = 0x4, eTQCmemo = 0x8, eTQCaccount = 0x10, eTQCreconciled = 0x20, eTQCaction = 0x40, eTQCshares = 0x80, eTQCprice = 0x100, eTQCperformance = 0x200, eTQCloan = 0x400, eTQCbalance = 0x800, eTQCend = 0x1000 };
@@ -314,13 +314,13 @@ public:
/**
* This method creates a TQDomElement for the @p document
* under the tqparent node @p tqparent. (This version overwrites the
* MMObject base class.)
*
* @param document reference to TQDomDocument
* @param tqparent reference to TQDomElement tqparent node
*/
- virtual void writeXML(TQDomDocument& document, TQDomElement& tqparent) const;
+ virtual void writeXML(TQDomDocument& document, TQDomElement& parent) const;
/**
* This method checks if a reference to the given object exists. It returns,
@@ -314,13 +314,13 @@ public:
/**
* This method creates a TQDomElement for the @p document
- * under the tqparent node @p tqparent. (This version overwrites the
+ * under the parent node @p parent. (This version overwrites the
* MMObject base class.)
*
@@ -314,13 +314,13 @@ public:
*
* @param document reference to TQDomDocument
- * @param tqparent reference to TQDomElement tqparent node
+ * @param parent reference to TQDomElement parent node
*/